@@ -8,25 +8,23 @@ class HTTPResponse:
         self.method = method.upper()
         self.status_message = None
         self.status_code = js_response.status
-        self.msg = js_response.statusText
         self._js_response = js_response
         self._body_buffer = body_buffer
         self._buffer_pointer = 0
+        self.expose_headers = self._js_response.headers.get(
+            "Access-Control-Expose-Headers"
+        )
 
     def __getitem__(self, key):
-        # Make sure we don't expose the Content-Encoding header in the browser
-        if key.lower() == "content-encoding":
-            return None
-        if key.lower() == "content-length":
-            return str(self._body_buffer.length)
         return self._js_response.headers.get(key)
 
     def get(self, key, default=None):
-        # Make sure we don't expose the Content-Encoding header in the browser
-        if key.lower() == "content-encoding":
-            return default
-        if key.lower() == "content-length":
-            return str(self._body_buffer.length)
+        if "content-encoding" == key.lower():
+            if self.expose_headers is None or (
+                "Content-Encoding" not in self.expose_headers
+                and "content-encoding" not in self.expose_headers
+            ):
+                return None
         return self._js_response.headers.get(key) or default
 
     def read(self, length=None):
